# !/bin/sh
#
# Author: Jean-Philippe Boily, jr. eng.
# Date: 13/05/2011
# Description: 	
#	This script will configure ClearOS' Apache server to redirect calls
#	made by Netborder SS7 to VoIP Media Gateway links to Netborder SS7 
#	web server.
# Return Code:
#	0 - No error
#	1 - Some files are missing
#		
# Copyright: Sangoma Technologies Corp. 2011

confFile=/usr/webconfig/conf/httpd.conf
proxyModule=/usr/lib/httpd/modules/mod_proxy.so
proxyHttpModule=/usr/lib/httpd/modules/mod_proxy_http.so
proxyConfig="
<IfModule proxy_module>
	ProxyRequests Off
	ProxyPass /fusionpbx http://127.0.0.1:8888/fusionpbx
	ProxyPassReverse /fusionpbx http://127.0.0.1:8888/fusionpbx
	ProxyPass /sangoma http://127.0.0.1:8888/fusionpbx/sangoma
	ProxyPassReverse /sangoma http://127.0.0.1:8888/fusionpbx/sangoma
	ProxyPass /mod http://127.0.0.1:8888/fusionpbx/mod
	ProxyPassReverse /mod http://127.0.0.1:8888/fusionpbx/mod
	ProxyPass /core http://127.0.0.1:8888/fusionpbx/core
	ProxyPassReverse /core http://127.0.0.1:8888/fusionpbx/core
	ProxyPass /style.css http://127.0.0.1:8888/style.css
	ProxyPassReverse /style.css http://127.0.0.1:8888/style.css
</IfModule>
"
sslEngineOn="SSLEngine on"
sslEngineOff="SSLEngine off"

# Validate httpd.conf presence
if [ ! -f $confFile ] ; then
	echo "ERROR - Could not find httpd configuration file $confFile"
	exit 1
fi

# Make sure that SSLEngine is off
isSSLEngineOn=$(grep -m1 "$sslEngineOn" < $confFile)

if [ ${#isSSLEngineOn} > 0 ] ; then
  sed -i "s|$sslEngineOn|$sslEngineOff|g" $confFile
fi

# Load proxy_module if not loaded
hasProxyModule=$(grep -m1 "LoadModule proxy_module" < $confFile)
hasProxyHttpModule=$(grep -m1 "LoadModule proxy_http_module" < $confFile)

if [ ${#hasProxyModule} == 0 ] ; then
	if [ -f $proxyModule ] ; then
		# proxy_module needs to be loaded before proxy_http_module
		if [ ${#hasProxyHttpModule} == 0 ] ; then
			echo "LoadModule proxy_module $proxyModule" >> $confFile
			echo "LoadModule proxy_http_module $proxyHttpModule" >> $confFile
			hasProxyHttpModule=true
		else
			sed -i "s|${hasProxyHttpModule}|LoadModule proxy_module ${proxyModule}\n${hasProxyHttpModule}|g" $confFile
			hasProxyHttpModule=true
		fi
	else
		echo "ERROR - Could not find file $proxyModule"
		exit 1
	fi
fi

# Load proxy_http_module if not loaded
if [ ${#hasProxyHttpModule} == 0 ] ; then
	if [ -f $proxyHttpModule ] ; then
		echo "LoadModule proxy_http_module $proxyHttpModule" >> $confFile
	else
		echo "ERROR - Could not find file $proxyHttpModule"
		exit 1
	fi
fi

# Add <IfModule proxy_module>
isProxyConfigured=$(grep -m1 -P "$proxyConfig" < $confFile)
if [ ${#isProxyConfigured} == 0 ] ; then
	echo "$proxyConfig" >> $confFile
fi

service httpd restart
service webconfig restart

exit 0

